@@ -3,7 +3,8 @@
 #' Use ggplot2 graphics to plot and customize the appearance of VPC.
 #' 
 #' @param x A \code{tidyvpcobj}.
-#' @param facet Should the resulting plot automatically facet by category? Only applicable for categorical VPC.
+#' @param facet Set to \code{TRUE} to facet plot by quantile (continuous VPC) or 
+#' category (categorical VPC).
 #' @param show.points Should the observed data points be plotted?
 #' @param show.boundaries Should the bin boundary be displayed?
 #' @param show.stats Should the VPC stats be displayed?
@@ -12,18 +13,50 @@
 #' @param ylab A character label for the y-axis.
 #' @param color A character vector of colors for the percentiles, from low to high.
 #' @param linetype A character vector of line type for the percentiles, from low to high.
-#' @param legend.position A character string specifying the position of the legend.
-#' @param facet.scales A character string specifying the \code{scales} argument to use for faceting.
+#' @param point.alpha Numeric value specifying transparency of points.
+#' @param point.size Numeric value specifying size of point.
+#' @param point.shape Character one of \code{"circle", "circle-fill", "diamond", "diamond-fill",
+#'  "square", "square-fill", "triangle-fill" , "triangle")}. Defaults to \code{"circle-fill"}.
+#' @param point.stroke Numeric value specifying size of point stroke.
+#' @param ribbon.alpha Numeric value specifying transparency of ribbon.
+#' @param legend.position A character string specifying the position of the legend. Options are 
+#' \code{"top", "bottom", "left", "right"}.
+#' @param facet.scales A character string specifying the \code{scales} argument to use for faceting. Options 
+#' are \code{"free", "fixed"}.
 #' @param custom.theme A character string specifying theme from ggplot2 package.
 #' @param ... Further arguments can be specified but are ignored.
 #' @return A \code{ggplot} object.
 #' @seealso
 #' \code{ggplot}
 #' @export
-plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.boundaries=TRUE, show.stats=!is.null(x$stats), show.binning=isFALSE(show.stats), xlab=NULL, ylab=NULL, color=c("red", "blue", "red"), linetype=c("dotted", "solid", "dashed"), legend.position="top", facet.scales="free", custom.theme = "ggplot2::theme_bw") {
+plot.tidyvpcobj <- function(x, 
+                            facet = FALSE,
+                            show.points=TRUE, 
+                            show.boundaries=TRUE, 
+                            show.stats=!is.null(x$stats), 
+                            show.binning=isFALSE(show.stats), 
+                            xlab=NULL, ylab=NULL, 
+                            color=c("red", "blue", "red"), 
+                            linetype=c("dotted", "solid", "dashed"),
+                            point.alpha = 0.4,
+                            point.size = 1,
+                            point.shape = "circle-fill",
+                            point.stroke = 1,
+                            ribbon.alpha = 0.1,
+                            legend.position="top", 
+                            facet.scales="free", 
+                            custom.theme = "ggplot2::theme_bw", #support function
+                            ...) {
   
   xbin <- lo <- hi <- qname <- md <- y <- xleft <- xright <- ypc <- l.ypc <- bin <- blq <- alq <- pname <-  NULL
   . <- list
+  
+  point_shape_vec <-  c("circle" = 1, "circle-fill" = 19,  "diamond" = 5, "diamond-fill" = 18,
+                        "square" = 0, "square-fill" = 15,  "triangle-fill" = 17, "triangle" = 2)
+  if(!point.shape %in% names(point_shape_vec))
+    stop(paste0("point.shape must be one of ", paste0(names(point_shape_vec), collapse = ", ")))
+  
+  point.shape <- as.numeric(point_shape_vec[names(point_shape_vec) == point.shape])
 
   vpc <- x
   
@@ -47,7 +80,7 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
     if (show.stats) {
       if (!is.null(vpc$rqss.obs.fits)) {
       g <- ggplot2::ggplot(vpc$stats, ggplot2::aes(x = x)) +
-        ggplot2::geom_ribbon(ggplot2::aes(ymin=lo, ymax=hi, fill=qname, col=qname, group=qname), alpha=0.1, col=NA) +
+        ggplot2::geom_ribbon(ggplot2::aes(ymin=lo, ymax=hi, fill=qname, col=qname, group=qname), alpha=ribbon.alpha, col=NA) +
         ggplot2::geom_line(ggplot2::aes(y=md, col=qname, group=qname)) +
         ggplot2::geom_line(ggplot2::aes(y=y, linetype=qname), size=1) +
         ggplot2::scale_colour_manual(
@@ -73,7 +106,7 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
         xlab("TIME")
     } else {
       g <- ggplot2::ggplot(vpc$stats, ggplot2::aes(x = xbin)) +
-        ggplot2::geom_ribbon(ggplot2::aes(ymin=lo, ymax=hi, fill=qname, col=qname, group=qname), alpha=0.1, col=NA) +
+        ggplot2::geom_ribbon(ggplot2::aes(ymin=lo, ymax=hi, fill=qname, col=qname, group=qname), alpha=ribbon.alpha, col=NA) +
         ggplot2::geom_line(ggplot2::aes(y=md, col=qname, group=qname)) +
         ggplot2::geom_line(ggplot2::aes(y=y, linetype=qname), size=1) +
         ggplot2::scale_colour_manual(
@@ -126,11 +159,13 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
       points.dat[, color := reorder2(factor(bin), x), by=vpc$strat]
       points.dat[, color := factor(color)]
       points.dat <- points.dat[!(blq|alq)]
-      g <- g + ggplot2::geom_point(data=points.dat, ggplot2::aes(x=x, y=y, color=color), size=1, alpha=0.4, show.legend=FALSE) +
+      g <- g + ggplot2::geom_point(data=points.dat, ggplot2::aes(x=x, y=y, color=color),
+                                   size=point.size, alpha=point.alpha, shape = point.shape, stroke = point.stroke, show.legend=FALSE) +
         ggplot2::scale_color_brewer(palette="Set1")
     } else {
       points.dat <- points.dat[!(blq|alq)]
-      g <- g + ggplot2::geom_point(data=points.dat, ggplot2::aes(x=x, y=y), size=1, alpha=0.4)
+      g <- g + ggplot2::geom_point(data=points.dat, ggplot2::aes(x=x, y=y), 
+                                   size=point.size, shape = point.shape, stroke = point.stroke, alpha=point.alpha)
     }
   }
   
@@ -157,17 +192,21 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
     }
   } else {
     if (!is.null(vpc$strat)) {
-      g <- g + ggplot2::facet_grid(vpc$strat.formula, scales=facet.scales)
+      if(length(as.list(vpc$strat.formula)) == 3) {
+        g <- g + ggplot2::facet_grid(vpc$strat.formula, scales=facet.scales)
+      } else {
+        g <- g + ggplot2::facet_wrap(names(vpc$strat), scales=facet.scales)
+      }
     }
   }
   
   } else {
     if(vpc$vpc.method$method == "binless"){
       g <- ggplot(vpc$stats, aes(x = x)) +
-        geom_ribbon(aes(ymin = lo, ymax = hi, fill = pname, col = pname, group = pname), alpha = 0.1, col = NA) +
+        geom_ribbon(aes(ymin = lo, ymax = hi, fill = pname, col = pname, group = pname), alpha = ribbon.alpha, col = NA) +
         geom_line(aes(y = md, col = pname, group = pname)) +
         geom_line(aes(y = y, linetype = pname), size = 1) +
-        geom_point(aes(x = x, y = y) ) +
+        geom_point(aes(x = x, y = y), size = point.size, alpha = point.alpha, shape = point.shape, stroke = point.stroke) +
         ylab(sprintf("Observed/Simulated probabilities and associated %s%% CI", 100*vpc$conf.level)) +
         xlab("TIME") +
         scale_colour_manual(name = sprintf("Simulated \nMedian (lines) %s%% CI (areas)",100*vpc$conf.level) , breaks = levels(vpc$stats$pname), values = .get_colors(length(levels(vpc$stats$pname))), labels = levels(vpc$stats$pname)) +
@@ -184,10 +223,10 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
       
     } else {
     g <- ggplot(vpc$stats, aes(x = xbin)) +
-      geom_ribbon(aes(ymin = lo, ymax = hi, fill = pname, col = pname, group = pname), alpha = 0.1, col = NA) +
+      geom_ribbon(aes(ymin = lo, ymax = hi, fill = pname, col = pname, group = pname), alpha = ribbon.alpha, col = NA) +
       geom_line(aes(y = md, col = pname, group = pname)) +
       geom_line(aes(y = y, linetype = pname), size = 1) +
-      geom_point(aes(x = xbin, y = y) ) +
+      geom_point(aes(x = xbin, y = y), size = point.size, alpha = point.alpha, shape = point.shape, stroke = point.stroke) +
       ylab(sprintf("Observed/Simulated probabilities and associated %s%% CI", 100*vpc$conf.level)) +
       xlab("TIME") +
       scale_colour_manual(name = sprintf("Simulated \nMedian (lines) %s%% CI (areas)",100*vpc$conf.level), breaks = levels(vpc$stats$pname), values = .get_colors(length(levels(vpc$stats$pname))), labels = levels(vpc$stats$pname)) +
@@ -223,48 +262,22 @@ plot.tidyvpcobj <- function(x, ..., facet = FALSE, show.points=TRUE, show.bounda
 
 
 .get_colors <- function(n){
-  if(n <= 1){
-    stop("Levels must be greater than 1")
-  }
-  if(n == 2){
-    colors <- c("green", "blue")
-  } else if(n == 3){
-    colors <- c("green", "blue", "red")
-  } else if(n == 4){
-    colors <- c("green", "blue", "red", "orange")
-  } else if(n == 5){
-    colors <- c("green", "blue", "red", "orange", "purple")
-  } else if(n == 6){
-    colors <- c("green", "blue", "red", "orange", "purple", "yellow")
-  }
+  stopifnot(n > 1 && n < 11)
   
-  colors
+  colors <- c("#59A14FE6","#4E79A7E6", "#E15759E6", "#F28E2BE6",
+              "#B07AA1E6", "#EDC948E6", "#FF9DA7E6", "#9C755FE6",
+              "#BAB0ACE6")
+  
+  colors[1:n]
 }
 
 
 
-
-
-
 .get_lines <- function(n){
-  if(n <= 1){
-    stop("Levels must be greater than 1")
-  }
-  if(n == 2){
-    lines <- c("solid", "dashed")
-  } else if(n == 3){
-    lines <- c("solid", "dashed", "dotted")
-  } else if(n == 4){
-    lines <- c("solid", "dashed", "dotted", "dotdash")
-  } else if(n == 5){
-    lines <- c("solid", "dashed", "dotted", "dotdash", "longdash")
-  } else if(n == 6){
-    lines <- c("solid", "dashed", "dotted", "dotdash", "longdash", "twodash")
-  }
+  stopifnot(n > 1 && n < 11)
   
-  lines
+  lines <- c("solid", "dashed", "dotted", "dotdash", "longdash",
+               "twodash", "solid", "dashed", "dotted", "dotdash")
+  
+  lines[1:n]
 }
-
-
-
-
